<?php
/**
 * Featured Slider section
 *
 * This is the template for the content of featured_slider section
 *
 * @package Theme Palace
 * @subpackage Blog Diary Pro
 * @since Blog Diary Pro 1.0.0
 */
if ( ! function_exists( 'blog_diary_pro_add_featured_slider_section' ) ) :
    /**
    * Add featured_slider section
    *
    *@since Blog Diary Pro 1.0.0
    */
    function blog_diary_pro_add_featured_slider_section() {
        $options = blog_diary_pro_get_theme_options();
        // Check if featured_slider is enabled on frontpage
        $featured_slider_enable = apply_filters( 'blog_diary_pro_section_status', true, 'featured_slider_section_enable' );

        if ( true !== $featured_slider_enable ) {
            return false;
        }
        // Get featured_slider section details
        $section_details = array();
        $section_details = apply_filters( 'blog_diary_pro_filter_featured_slider_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render featured_slider section now.
        blog_diary_pro_render_featured_slider_section( $section_details );
    }
endif;

if ( ! function_exists( 'blog_diary_pro_get_featured_slider_section_details' ) ) :
    /**
    * featured_slider section details.
    *
    * @since Blog Diary Pro 1.0.0
    * @param array $input featured_slider section details.
    */
    function blog_diary_pro_get_featured_slider_section_details( $input ) {
        $options = blog_diary_pro_get_theme_options();

        // Content type.
        $featured_slider_count = ! empty( $options['featured_slider_count'] ) ? $options['featured_slider_count'] : 8;
        $cats= ! empty( $options['featured_slider_categories'] ) ? $options['featured_slider_categories'] : '';
        
        if ( empty( $cats ) )
            return;

        $content = array();
        $i = 0;
        foreach ( $cats as $cat_id ) :
            $content[$i] = array();
            $args = array(
                'post_type'         => 'post',
                'posts_per_page'    => $featured_slider_count,
                'cat'               => absint( $cat_id ),
                'ignore_sticky_posts'   => true,
                ); 

            // Run The Loop.
                $query = new WP_Query( $args );
                if ( $query->have_posts() ) : 
                    while ( $query->have_posts() ) : $query->the_post();
                        $page_post[$i]['id']        = get_the_id();
                        $page_post[$i]['title']     = get_the_title();
                        $page_post[$i]['url']       = get_the_permalink();
                        $page_post[$i]['excerpt']   = blog_diary_pro_trim_content( 25 );
                        $page_post[$i]['author']    = blog_diary_pro_author();
                        $page_post[$i]['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';


                        // Push to the main array.
                        array_push( $content[$i], $page_post[$i] );
                    endwhile;
                endif;
                wp_reset_postdata();
                $i++;
            endforeach;

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// featured_slider section content details.
add_filter( 'blog_diary_pro_filter_featured_slider_section_details', 'blog_diary_pro_get_featured_slider_section_details' );


if ( ! function_exists( 'blog_diary_pro_render_featured_slider_section' ) ) :
  /**
   * Start featured_slider section
   *
   * @return string featured_slider content
   * @since Blog Diary Pro 1.0.0
   *
   */
   function blog_diary_pro_render_featured_slider_section( $content_details = array() ) {
        $options = blog_diary_pro_get_theme_options();
        $cats= ! empty( $options['featured_slider_categories'] ) ? $options['featured_slider_categories'] : '';
        $read_more = ! empty( $options['featured_slider_btn_title'] ) ? $options['featured_slider_btn_title'] : esc_html__( 'Read More', 'blog-diary-pro' );

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="featured-post" class="col-2 page-section no-padding-bottom clear">
            <?php $i = 0; 
                $d = 1;
                foreach ( $content_details as $content_detail ) : ?>
                    <div class="regular hentry" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 500, "dots": false, "arrows":true, "autoplay":<?php echo $options['featured_slider_autoplay_enable'] ? 'true': 'false'; ?>, "draggable": true, "fade": false }'>
                        <div class="education-wrapper <?php echo ( $d%2 == 0 ) ? 'design' : ''; ?> ">
                            <?php $c = 1;
                            foreach ( $content_detail as $content ) : ?>
                                <article>
                                    <?php if ( $c%4 == 1 || $c === 1 ) : ?>
                                        <div class="section-header">
                                            <h2 class="section-title">
                                                <a href="<?php echo esc_url( get_category_link( $cats[$i] ) ) ?>"><?php echo esc_html( get_cat_name( $cats[$i] ) ); ?>
                                                </a>
                                            </h2>
                                        </div><!-- .section-header -->
                                    <?php endif; ?>

                                    <div class="featured-image">
                                        <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['image'] ); ?>"></a>
                                    </div>

                                    <div class="entry-container">

                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                        </header>

                                        <div class="entry-meta">
                                        <?php 
                                            echo wp_kses_post( $content['author'] );
                                            blog_diary_pro_posted_on( $content['id'] ); ?>
                                            <span class="cat-links">
                                                <?php the_category( '', '', $content['id'] ); ?>
                                            </span><!-- .cat-links -->
                                        </div><!-- .entry-meta -->

                                        <div class="entry-content">
                                            <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                        </div>
                                        <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn">
                                            <span class="screen-reader-text"><?php echo esc_html( $content['title'] ); ?></span>
                                            <?php echo esc_html( $read_more ); ?>
                                        </a>
                                    </div>
                                </article><!-- .hentry -->
                            <?php if ( $c%4 == 0 && count( $content_detail ) !== $c ) : ?>
                                </div>
                                <div class="education-wrapper <?php echo ( $d%2 == 0 ) ? 'design' : ''; ?>">
                            <?php endif; ?>
                            <?php $c++;  endforeach; ?>
                        </div>
                    </div><!-- .regular -->
            <?php
             $i++;
             $d++;
            endforeach; ?>
        </div><!-- #featured-post -->
    <?php
    }    
endif;
